@@ -507,7 +507,7 @@ def commit_app(project_name, **settings_patches):
 
 @task
 @beanstalk_role('server')
-def add_user(tmp_key_path):
+def add_user(tmp_key_path, clean_tmp_key=False):
     """Add a user's SSH public key to beanstalk
     """
     tmp_key_path = os.path.expanduser(tmp_key_path)
@@ -526,7 +526,10 @@ def add_user(tmp_key_path):
                 break
 
     if not has_this_key:
+        # NOTE: Be careful that new_key may contains " (double quote)
         local('cp {0} {0}.bak && echo "{1}" >> {0} && rm -rf {0}.bak'.format(authorized_keys_path, new_key))
 
-    print green('User added.')
+    if clean_tmp_key:
+        local('rm -rf {path}'.format(path=tmp_key_path))
 
+    print green('User added.')
