@@ -1,3 +1,4 @@
+import hashlib
 from fabric.api import *
 from ground_soil.filesystem import rsync
 from beanstalk.decorators import beanstalk_role
@@ -21,14 +22,17 @@ def add(**settings_patches):
     # Get ssh public key
     ssh_pub_key_path = prompt('Where\'s your ssh public key?', default='~/.ssh/id_rsa.pub',
                               validate=validate_file_existence)
+    with open(ssh_pub_key_path, 'r') as f:
+        key_content = f.read().strip()
+    hash_key = hashlib.md5(key_content)[:16]
+    tmp_path = '/tmp/beanstalk-stack/pub_key.{hash}.tmp'.format(hash=hash_key)
 
     @roles('web_servers')
     def add_user_core():
         host_name = env.host_string.split('@')[-1]
-        tmp_path = '~/key.tmp'
 
         local(rsync(ssh_pub_key_path, 'beanstalk@{host}:{key_path}'.format(host=host_name, key_path=tmp_path)))
-        run('bsjack server.add_user:{key_path}'.format(key_path=tmp_path))
+        run('bsjack server.add_user:{key_path},clean_tmp_key=True'.format(key_path=tmp_path))
 
     with settings(hide('running')):
         # TODO: Should not prompt beanstalk's SSH password
